@@ -3,8 +3,8 @@
 
 use fil_actors_runtime::runtime::{ActorCode, Runtime};
 use fil_actors_runtime::{
-    actor_error, make_map_with_root_and_bitwidth, resolve_to_id_addr, wasm_trampoline,
-    ActorDowncast, ActorError, Map, STORAGE_MARKET_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
+    actor_error, make_map_with_root_and_bitwidth, resolve_to_id_addr, ActorDowncast, ActorError,
+    Map, STORAGE_MARKET_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
 use fvm_ipld_blockstore::Blockstore;
 use fvm_ipld_encoding::RawBytes;
@@ -19,7 +19,8 @@ use num_traits::{FromPrimitive, Signed, Zero};
 pub use self::state::State;
 pub use self::types::*;
 
-wasm_trampoline!(Actor);
+#[cfg(feature = "fil-actor")]
+fil_actors_runtime::wasm_trampoline!(Actor);
 
 mod state;
 mod types;
@@ -52,10 +53,10 @@ impl Actor {
         // root should be an ID address
         let id_addr = rt
             .resolve_address(&root_key)
-            .ok_or_else(|| actor_error!(ErrIllegalArgument, "root should be an ID address"))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_ARGUMENT, "root should be an ID address"))?;
 
         let st = State::new(rt.store(), id_addr).map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "Failed to create verifreg state")
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "Failed to create verifreg state")
         })?;
 
         rt.create(&st)?;
@@ -69,7 +70,7 @@ impl Actor {
     {
         if &params.allowance < &MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "Allowance {} below minimum deal size for add verifier {}",
                 params.allowance,
                 params.address
@@ -78,7 +79,7 @@ impl Actor {
 
         let verifier = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
@@ -87,7 +88,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&st.root_key))?;
 
         if verifier == st.root_key {
-            return Err(actor_error!(ErrIllegalArgument, "Rootkey cannot be added as verifier"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT, "Rootkey cannot be added as verifier"));
         }
 
         rt.transaction(|st: &mut State, rt| {
@@ -95,7 +96,7 @@ impl Actor {
                 make_map_with_root_and_bitwidth(&st.verifiers, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::ErrIllegalState,
+                            ExitCode::USR_ILLEGAL_STATE,
                             "failed to load verified clients",
                         )
                     })?;
@@ -105,28 +106,28 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verified clients")
             })?;
 
             let found = verified_clients.contains_key(&verifier.to_bytes()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to get client state for {}", verifier),
                 )
             })?;
             if found {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "verified client {} cannot become a verifier",
                     verifier
                 ));
             }
 
             verifiers.set(verifier.to_bytes().into(), BigIntDe(params.allowance.clone())).map_err(
-                |e| e.downcast_default(ExitCode::ErrIllegalState, "failed to add verifier"),
+                |e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to add verifier"),
             )?;
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
             })?;
 
             Ok(())
@@ -142,7 +143,7 @@ impl Actor {
     {
         let verifier = resolve_to_id_addr(rt, &verifier_addr).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve addr {} to ID addr", verifier_addr),
             )
         })?;
@@ -157,19 +158,19 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verified clients")
             })?;
             verifiers
                 .delete(&verifier.to_bytes())
                 .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to remove verifier")
+                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to remove verifier")
                 })?
                 .ok_or_else(|| {
-                    actor_error!(ErrIllegalArgument, "failed to remove verifier: not found")
+                    actor_error!(USR_ILLEGAL_ARGUMENT, "failed to remove verifier: not found")
                 })?;
 
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
             })?;
             Ok(())
         })?;
@@ -190,7 +191,7 @@ impl Actor {
 
         if params.allowance < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "Allowance {} below MinVerifiedDealSize for add verified client {}",
                 params.allowance,
                 params.address
@@ -199,14 +200,14 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         let st: State = rt.state()?;
         if client == st.root_key {
-            return Err(actor_error!(ErrIllegalArgument, "Rootkey cannot be added as verifier"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT, "Rootkey cannot be added as verifier"));
         }
 
         rt.transaction(|st: &mut State, rt| {
@@ -214,14 +215,17 @@ impl Actor {
                 make_map_with_root_and_bitwidth(&st.verifiers, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::ErrIllegalState,
+                            ExitCode::USR_ILLEGAL_STATE,
                             "failed to load verified clients",
                         )
                     })?;
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                    e.downcast_default(
+                        ExitCode::USR_ILLEGAL_STATE,
+                        "failed to load verified clients",
+                    )
                 })?;
 
             // Validate caller is one of the verifiers.
@@ -230,21 +234,21 @@ impl Actor {
                 .get(&verifier.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to get Verifier {}", verifier),
                     )
                 })?
                 .ok_or_else(|| {
-                    actor_error!(ErrNotFound, format!("no such Verifier {}", verifier))
+                    actor_error!(USR_NOT_FOUND, format!("no such Verifier {}", verifier))
                 })?;
 
             // Validate client to be added isn't a verifier
             let found = verifiers.contains_key(&client.to_bytes()).map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to get verifier")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to get verifier")
             })?;
             if found {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "verifier {} cannot be added as a verified client",
                     client
                 ));
@@ -253,7 +257,7 @@ impl Actor {
             // Compute new verifier cap and update.
             if verifier_cap < &params.allowance {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "Add more DataCap {} for VerifiedClient than allocated {}",
                     params.allowance,
                     verifier_cap
@@ -263,14 +267,14 @@ impl Actor {
 
             verifiers.set(verifier.to_bytes().into(), BigIntDe(new_verifier_cap)).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("Failed to update new verifier cap for {}", verifier),
                 )
             })?;
 
             let client_cap = verified_clients.get(&client.to_bytes()).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("Failed to get verified client {}", client),
                 )
             })?;
@@ -285,7 +289,7 @@ impl Actor {
             verified_clients.set(client.to_bytes().into(), BigIntDe(client_cap.clone())).map_err(
                 |e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!(
                             "Failed to add verified client {} with cap {}",
                             client, client_cap,
@@ -295,10 +299,10 @@ impl Actor {
             )?;
 
             st.verifiers = verifiers.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verifiers")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verifiers")
             })?;
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verified clients")
             })?;
 
             Ok(())
@@ -319,14 +323,14 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         if params.deal_size < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "Verified Dealsize {} is below minimum in usedbytes",
                 params.deal_size
             ));
@@ -336,21 +340,24 @@ impl Actor {
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                    e.downcast_default(
+                        ExitCode::USR_ILLEGAL_STATE,
+                        "failed to load verified clients",
+                    )
                 })?;
 
             let BigIntDe(vc_cap) = verified_clients
                 .get(&client.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to get verified client {}", &client),
                     )
                 })?
-                .ok_or_else(|| actor_error!(ErrNotFound, "no such verified client {}", client))?;
+                .ok_or_else(|| actor_error!(USR_NOT_FOUND, "no such verified client {}", client))?;
             if vc_cap.is_negative() {
                 return Err(actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "negative cap for client {}: {}",
                     client,
                     vc_cap
@@ -359,7 +366,7 @@ impl Actor {
 
             if &params.deal_size > vc_cap {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "Deal size of {} is greater than verifier_cap {} for verified client {}",
                     params.deal_size,
                     vc_cap,
@@ -375,13 +382,13 @@ impl Actor {
                     .delete(&client.to_bytes())
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::ErrIllegalState,
+                            ExitCode::USR_ILLEGAL_STATE,
                             format!("Failed to delete verified client {}", client),
                         )
                     })?
                     .ok_or_else(|| {
                         actor_error!(
-                            ErrIllegalState,
+                            USR_ILLEGAL_STATE,
                             "Failed to delete verified client {}: not found",
                             client
                         )
@@ -390,7 +397,7 @@ impl Actor {
                 verified_clients.set(client.to_bytes().into(), BigIntDe(new_vc_cap)).map_err(
                     |e| {
                         e.downcast_default(
-                            ExitCode::ErrIllegalState,
+                            ExitCode::USR_ILLEGAL_STATE,
                             format!("Failed to update verified client {}", client),
                         )
                     },
@@ -398,7 +405,7 @@ impl Actor {
             }
 
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verified clients")
             })?;
             Ok(())
         })?;
@@ -416,7 +423,7 @@ impl Actor {
         rt.validate_immediate_caller_is(std::iter::once(&*STORAGE_MARKET_ACTOR_ADDR))?;
         if params.deal_size < *MINIMUM_VERIFIED_DEAL_SIZE {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "Below minimum VerifiedDealSize requested in RestoreBytes: {}",
                 params.deal_size
             ));
@@ -424,21 +431,24 @@ impl Actor {
 
         let client = resolve_to_id_addr(rt, &params.address).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 format!("failed to resolve addr {} to ID addr", params.address),
             )
         })?;
 
         let st: State = rt.state()?;
         if client == st.root_key {
-            return Err(actor_error!(ErrIllegalArgument, "Cannot restore allowance for Rootkey"));
+            return Err(actor_error!(USR_ILLEGAL_ARGUMENT, "Cannot restore allowance for Rootkey"));
         }
 
         rt.transaction(|st: &mut State, rt| {
             let mut verified_clients =
                 make_map_with_root_and_bitwidth(&st.verified_clients, rt.store(), HAMT_BIT_WIDTH)
                     .map_err(|e| {
-                    e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                    e.downcast_default(
+                        ExitCode::USR_ILLEGAL_STATE,
+                        "failed to load verified clients",
+                    )
                 })?;
             let verifiers = make_map_with_root_and_bitwidth::<_, BigIntDe>(
                 &st.verifiers,
@@ -446,16 +456,16 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verifiers")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verifiers")
             })?;
 
             // validate we are NOT attempting to do this for a verifier
             let found = verifiers.contains_key(&client.to_bytes()).map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to get verifier")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to get verifier")
             })?;
             if found {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "cannot restore allowance for a verifier {}",
                     client
                 ));
@@ -466,7 +476,7 @@ impl Actor {
                 .get(&client.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to get verified client {}", &client),
                     )
                 })?
@@ -477,13 +487,13 @@ impl Actor {
             let new_vc_cap = vc_cap + &params.deal_size;
             verified_clients.set(client.to_bytes().into(), BigIntDe(new_vc_cap)).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("Failed to put verified client {}", client),
                 )
             })?;
 
             st.verified_clients = verified_clients.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to flush verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to flush verified clients")
             })?;
             Ok(())
         })?;
@@ -502,7 +512,7 @@ impl Actor {
     {
         let client = resolve_to_id_addr(rt, &params.verified_client_to_remove).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalArgument,
+                ExitCode::USR_ILLEGAL_ARGUMENT,
                 format!(
                     "failed to resolve client addr {} to ID addr",
                     params.verified_client_to_remove
@@ -513,7 +523,7 @@ impl Actor {
         let verifier_1 =
             resolve_to_id_addr(rt, &params.verifier_request_1.verifier).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalArgument,
+                    ExitCode::USR_ILLEGAL_ARGUMENT,
                     format!(
                         "failed to resolve verifier addr {} to ID addr",
                         params.verifier_request_1.verifier
@@ -524,7 +534,7 @@ impl Actor {
         let verifier_2 =
             resolve_to_id_addr(rt, &params.verifier_request_2.verifier).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalArgument,
+                    ExitCode::USR_ILLEGAL_ARGUMENT,
                     format!(
                         "failed to resolve verifier addr {} to ID addr",
                         params.verifier_request_2.verifier
@@ -534,7 +544,7 @@ impl Actor {
 
         if verifier_1 == verifier_2 {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "need two different verifiers to send remove datacap request"
             ));
         }
@@ -550,12 +560,12 @@ impl Actor {
                 HAMT_BIT_WIDTH,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verified clients")
             })?;
 
             // check that `client` is currently a verified client
             if !is_verifier(rt, st, client)? {
-                return Err(actor_error!(ErrNotFound, "{} is not a verified client", client));
+                return Err(actor_error!(USR_NOT_FOUND, "{} is not a verified client", client));
             }
 
             // get existing cap allocated to client
@@ -563,7 +573,7 @@ impl Actor {
                 .get(&client.to_bytes())
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to get verified client {}", &client),
                     )
                 })?
@@ -572,12 +582,12 @@ impl Actor {
 
             // check that `verifier_1` is currently a verified client
             if !is_verifier(rt, st, verifier_1)? {
-                return Err(actor_error!(ErrNotFound, "{} is not a verified client", verifier_1));
+                return Err(actor_error!(USR_NOT_FOUND, "{} is not a verified client", verifier_1));
             }
 
             // check that `verifier_2` is currently a verified client
             if !is_verifier(rt, st, verifier_2)? {
-                return Err(actor_error!(ErrNotFound, "{} is not a verified client", verifier_2));
+                return Err(actor_error!(USR_NOT_FOUND, "{} is not a verified client", verifier_2));
             }
 
             // validate signatures
@@ -588,7 +598,7 @@ impl Actor {
             )
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to load datacap removal proposal ids",
                 )
             })?;
@@ -616,7 +626,7 @@ impl Actor {
                 // no DataCap remaining, delete verified client
                 verified_clients.delete(&client.to_bytes()).map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to delete verified client {}", &client),
                     )
                 })?;
@@ -627,7 +637,7 @@ impl Actor {
                     .set(BytesKey::from(client.to_bytes()), BigIntDe(new_data_cap))
                     .map_err(|e| {
                         e.downcast_default(
-                            ExitCode::ErrIllegalState,
+                            ExitCode::USR_ILLEGAL_STATE,
                             format!("failed to update datacap for verified client {}", &client),
                         )
                     })?;
@@ -636,14 +646,14 @@ impl Actor {
 
             st.remove_data_cap_proposal_ids = proposal_ids.flush().map_err(|e| {
                 actor_error! {
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "failed to flush proposal ids: {}",
                     e
                 }
             })?;
             st.verified_clients = verified_clients.flush().map_err(|e| {
                 actor_error! {
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "failed to flush verified clients: {}",
                     e
                 }
@@ -669,13 +679,13 @@ where
         HAMT_BIT_WIDTH,
     )
     .map_err(|e| {
-        e.downcast_default(ExitCode::ErrIllegalState, "failed to load verified clients")
+        e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load verified clients")
     })?;
 
     // check that the `address` is currently a verified client
     let found = verified_clients
         .contains_key(&address.to_bytes())
-        .map_err(|e| e.downcast_default(ExitCode::ErrIllegalState, "failed to get verifier"))?;
+        .map_err(|e| e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to get verifier"))?;
 
     Ok(found)
 }
@@ -692,7 +702,7 @@ where
 
     let maybe_id = proposal_ids.get(&key.to_bytes()).map_err(|e| {
         actor_error!(
-            ErrIllegalState,
+            USR_ILLEGAL_STATE,
             "failed to get proposal id for verifier {} and client {}: {}",
             verifier,
             client,
@@ -709,7 +719,7 @@ where
     let next_id = RemoveDataCapProposalID(curr_id.0 + 1);
     proposal_ids.set(BytesKey::from(key.to_bytes()), next_id.clone()).map_err(|e| {
         actor_error!(
-            ErrIllegalState,
+            USR_ILLEGAL_STATE,
             "failed to update proposal id for verifier {} and client {}: {}",
             verifier,
             client,
@@ -739,12 +749,12 @@ where
 
     let b = RawBytes::serialize(proposal).map_err(|e| {
         actor_error!(
-                ErrSerialization; "failed to marshal remove datacap request: {}", e)
+                USR_SERIALIZATION; "failed to marshal remove datacap request: {}", e)
     })?;
 
     // verify signature of proposal
     rt.verify_signature(&request.signature, &request.verifier, &b).map_err(|e|{
-        actor_error!(ErrIllegalArgument; "invalid signature for datacap removal request: {}", e)
+        actor_error!(USR_ILLEGAL_ARGUMENT; "invalid signature for datacap removal request: {}", e)
     })
 }
 
@@ -787,7 +797,7 @@ impl ActorCode for Actor {
                 Self::remove_verified_client_data_cap(rt, rt.deserialize_params(params)?)?;
                 Ok(RawBytes::default())
             }
-            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
+            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
         }
     }
 }
